@@ -1,5 +1,5 @@
 /*
- *  Copyright (C) 2000 Marco Pesenti Gritti
+ *  Copyright © 2000 Marco Pesenti Gritti
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -19,7 +19,7 @@
 #ifndef ERROR_VIEWER_MOZILLA_LINK_CHECKER_H
 #define ERROR_VIEWER_MOZILLA_LINK_CHECKER_H
 
-#include <epiphany/ephy-embed.h>
+#include <epiphany/epiphany.h>
 
 #include "link-checker.h"
 
